Package 'hashr'
| Title: |
Hash R Objects to Integers Fast |
| Description: |
Apply an adaptation of the SuperFastHash algorithm to any
R object. Hash whole R objects or, for vectors or lists, hash R
objects to obtain a set of hash values that is stored in a
structure equivalent to the input. See
<http://www.azillionmonkeys.com/qed/hash.html> for a
description of the hash algorithm. |
| Authors: |
Mark van der Loo [aut, cre],
Paul Hsieh [ctb] |
| Maintainer: |
Mark van der Loo <[email protected]> |
| License: |
GPL-3 |
| Version: |
0.1.4 |
| Built: |
2026-06-01 12:05:10 UTC |
| Source: |
https://github.com/markvanderloo/hashr |
Help Index